@@ -10,16 +10,16 @@ namespace vivid
     {
     private:
         std::vector<size_t> mPoints = {};
-        coord_t mUVcoord = 0;
+        normal_float mUVcoord = 0;
 
     public:
-        inline CFace(const std::vector<size_t> &arPoints, coord_t aColor) : mPoints(arPoints), mUVcoord(max(0.0 , min(aColor , 1.))){}
+        inline CFace(const std::vector<size_t> &arPoints, normal_float aColor) : mPoints(arPoints), mUVcoord(aColor){}
         //operator=
         inline ~CFace(){}
 
         inline std::vector<size_t> GetPoints()const  { return mPoints; }
         inline size_t operator[](size_t I) {return mPoints[I];}
-        inline coord_t GetUVcoord() const { return mUVcoord; }
+        inline normal_float GetUVcoord() const { return mUVcoord; }
 
         // todo: is this needed?
         inline void SetUVcoord(const coord_t aColor) { mUVcoord = aColor; }
