@@ -26,7 +26,7 @@ void CModel::ExportToObj(const string &arOutputFilePath, bool WithTexture){
     OBJExporter(*this, arOutputFilePath, WithTexture);
 }
 
-int CModel::Export(const std::string &arOutputFilePath, std::string aFileType){
-    return CAssimpExport::AssimpExporter(*this, aFileType, arOutputFilePath);
+int CModel::Export(const std::string &arOutputFilePath, const std::string& arFileType){
+    return AssimpExport::AssimpExporter(*this, arFileType, arOutputFilePath);
 }
 CModel::~CModel() = default;
\ No newline at end of file
