@@ -6,7 +6,7 @@
 namespace vivid
 {
 
-CMesh SurfByFunc(const F3D_t &func, int aBoxSize, coord_t aAlpha, const std::string &arLabel, bool RemoveFlatSurfaces) {
+CMesh SurfByFunc(const F3D_t &func, int aBoxSize, normal_float aOpacity, const std::string &arLabel, bool RemoveFlatSurfaces) {
     // Creating Wireframe
     aBoxSize *= SUBDIVISION_FACTOR;
     vector<CPoint> points = {};
@@ -15,7 +15,7 @@ CMesh SurfByFunc(const F3D_t &func, int aBoxSize, coord_t aAlpha, const std::str
 //            points.push_back(CPoint(i,i,0.));
 //        }
 //    }
-    vector<coord_t> UV_coords = {};
+    vector<normal_float> quan = {};
     coord_t temp_x, temp_y;
 
     for (int x = -aBoxSize; x <= aBoxSize; x += 1) {
@@ -33,7 +33,7 @@ CMesh SurfByFunc(const F3D_t &func, int aBoxSize, coord_t aAlpha, const std::str
             }
             CPoint point = {temp_x,z,temp_y};
             points.push_back(point);
-            UV_coords.push_back(z);
+            quan.push_back((float)z);
         }
     }
 
@@ -42,21 +42,21 @@ CMesh SurfByFunc(const F3D_t &func, int aBoxSize, coord_t aAlpha, const std::str
             points[i] = CPoint(points[i].X(), 0, points[i].Z());
         }
     }
-    coord_t v_max = *max_element(UV_coords.begin(), UV_coords.end());
-    coord_t v_min = *min_element(UV_coords.begin(), UV_coords.end());
+    coord_t v_max = *max_element(quan.begin(), quan.end());
+    coord_t v_min = *min_element(quan.begin(), quan.end());
     if (v_max <= 0) {
         v_max = v_min;
-        v_min = *max_element(UV_coords.begin(), UV_coords.end());
+        v_min = *max_element(quan.begin(), quan.end());
     }
     coord_t divide_by = 1. / (v_max - v_min);
 
     for (int i = 0; i < points.size(); i++) {
-        UV_coords[i] = (UV_coords[i] - v_min) * divide_by;
+        quan[i] = (quan[i] - v_min) * divide_by;
     }
     vector<CFace> faces;
     for (size_t i = 0; i < (2*aBoxSize)*(2*aBoxSize); i += aBoxSize*2+1) {
         for (size_t j = 0; j < 2*(aBoxSize); j += 1) {
-            coord_t color = (UV_coords[i + j] + UV_coords[i + j + 1] + UV_coords[i + 2 * aBoxSize + j + 1] + UV_coords[i + 2 * aBoxSize + j]) / 4.;
+            coord_t color = (quan[i + j] + quan[i + j + 1] + quan[i + 2 * aBoxSize + j + 1] + quan[i + 2 * aBoxSize + j]) / 4.;
             //            if (!(isinf(points[i+j].Y()) & isinf(points[i+j+1].Y()) & isinf(points[i+j+2+2*aBoxSize].Y()) & isinf(points[i+j+1+2*aBoxSize].Y()))) {
             //                faces.push_back(CFace({i + j, i + (j + 1), i + 2*aBoxSize + (j + 2), i + 2*aBoxSize + j + 1}, color));
             //                cout << i + j << " " << i + (j + 1) << " " << i + 2*aBoxSize + (j + 2) << " " << i + 2*aBoxSize + j + 1<< endl;
@@ -73,12 +73,12 @@ CMesh SurfByFunc(const F3D_t &func, int aBoxSize, coord_t aAlpha, const std::str
         }
     }
 
-    CMesh mesh = CMesh(points, faces, arLabel, aAlpha);
+    CMesh mesh = CMesh(points, faces, arLabel, aOpacity);
     return mesh;
 }
 
 CMesh ParametricSurface(const FParametric_t &func, int aNumberOfSteps, coord_t aThetaMin, coord_t aThetaMax,
-                        coord_t aPhiMin, coord_t aPhiMax, coord_t aAlpha, const std::string &arLabel)
+                        coord_t aPhiMin, coord_t aPhiMax, normal_float aOpacity, const std::string &arLabel)
 {
     vector<CPoint> points;
     vector<CFace> faces;
@@ -116,7 +116,7 @@ CMesh ParametricSurface(const FParametric_t &func, int aNumberOfSteps, coord_t a
     {
         faces.push_back(CFace(vector<size_t>{0, 2 + (i + 1) * aNumberOfSteps, 2 + i * aNumberOfSteps}, aColor)); //creates triangles
     }
-    faces.push_back(CFace(vector<size_t>{0, 2, 2 + (aNumberOfSteps - 1) * aNumberOfSteps}, aColor));
+    faces.push_back(CFace(vector<size_t>{0, 2, (size_t)2 + (aNumberOfSteps - 1) * aNumberOfSteps}, aColor));
 
     /* Add rectangular faces around center */
     for (size_t i = 2; i < 1 + aNumberOfSteps; i++)
@@ -135,9 +135,9 @@ CMesh ParametricSurface(const FParametric_t &func, int aNumberOfSteps, coord_t a
     {
         faces.push_back(CFace(vector<size_t>{1, 1 + (i + 1) * aNumberOfSteps, 1 + (i + 2) * aNumberOfSteps}, aColor));
     }
-    faces.push_back(CFace(vector<size_t>{1, 1 + (aNumberOfSteps) * aNumberOfSteps, 1 + aNumberOfSteps}, aColor));
+    faces.push_back(CFace(vector<size_t>{1, (size_t)1 + (aNumberOfSteps) * aNumberOfSteps, (size_t)1 + aNumberOfSteps}, aColor));
 
-    CMesh mesh(points, faces, arLabel, aAlpha);
+    CMesh mesh(points, faces, arLabel, aOpacity);
 //    mesh.MoveMesh(arCenter);
 //    mesh.ScaleMesh(CPoint(aRadius, aRadius, aRadius));
 
